Clojure only.

beancount-reds-plugins.opengroup.opengroup


raw-xfclj

(raw-xf {:keys [config options]})

Port from original plugin in Python with the same license, GPL 3.0.

https://github.com/redstreet/beancount_reds_plugins/tree/main/beancount_reds_plugins/opengroup

Differences:

  • regexes use e.g. ?<root> instead of ?P<root>, and the Clojure regex reader prefix #
  • named capture groups cannot contain underscores
  • template strings use double braces, mustache style, rather than single brace Python f-string style
Port from original plugin in Python with the same license, GPL 3.0.

https://github.com/redstreet/beancount_reds_plugins/tree/main/beancount_reds_plugins/opengroup

Differences:
- regexes use e.g. ?<root> instead of ?P<root>, and the Clojure regex reader prefix #
- named capture groups cannot contain underscores
- template strings use double braces, mustache style, rather than single brace Python f-string style
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries