Clojure only.

limabean.contrib.plugins.examples.magic-money


booked-xfclj

(booked-xf {:keys [config options]})

Stateful transducer on booked directives to add money to each account which is opened.

For an explanation of transducers, see https://clojure.org/reference/transducers

Stateful transducer on booked directives to add money to each account which is opened.

For an explanation of transducers, see https://clojure.org/reference/transducers
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries