(booked-xf {:keys [config options]})Stateful transducer on booked directives to add money to each account which is opened.
For an explanation of transducers, see https://clojure.org/reference/transducers
Stateful transducer on booked directives to add money to each account which is opened. For an explanation of transducers, see https://clojure.org/reference/transducers
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |